@@ -32,7 +32,7 @@ class TQVBoxLayout;
 class TQWidget;
 class KIntNumInput;
 class ConfDialog : public KDialogBase, public GUIModeSelector {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         ConfDialog( TQWidget* parent = 0, const char* name = 0 );
