@@ -33,7 +33,7 @@ class TDEListView;
 class KPushButton;
 
 class HelpDialogData : public TQObject {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         HelpDialogData() {}
@@ -74,7 +74,7 @@ class HelpDialogData : public TQObject {
 
 class HelpDialog : public TQDialog
 { 
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         HelpDialog( HelpDialogData* data, TQWidget* parent = 0,
