@@ -26,7 +26,7 @@ class TQPopupMenu;
 class TQTimer;
 
 class KMyHistoryCombo : public KHistoryCombo  {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         /** Create a new KMyHistoryCombo which has automatic KRename default history
