@@ -36,7 +36,7 @@ class TQPixmap;
 class TQPainter;
 class TQPoint;
 class KMyListBox : public TDEListBox  {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         enum { ASCENDING = 1, DESCENDING = 2, RANDOM = 3, NUMMERIC = 4, UNSORTED = 0 };
