@@ -27,7 +27,7 @@
 
 class KMyIntSpinBox : public KIntSpinBox
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         KMyIntSpinBox( TQWidget* parent )
@@ -45,7 +45,7 @@ class KIntNumInput;
 class TDEListBox;
 class KPushButton;
 class NumberDialog : public KDialogBase  {
-   Q_OBJECT
+   TQ_OBJECT
   
     public: 
         NumberDialog(TQValueList<int> & n,TQWidget *parent=0);
