@@ -35,7 +35,7 @@ class TQListViewItem;
 class TDEListView;
 class ReplaceDialog : public KDialogBase
 { 
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
