@@ -34,7 +34,7 @@
 @author Dominik Seichter
 */
 class TranslitPlugin : public Plugin {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         const TQString getName() const;
